"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBlockCategoryUpdateValidation = exports.createBlockCategoryCreateValidation = void 0;
var _zod = _interopRequireDefault(require("zod"));
const createBlockCategoryCreateValidation = () => {
  return _zod.default.object({
    slug: _zod.default.string().max(100).refine(value => {
      if (!value) {
        return false;
      } else if (value.match(/^[a-z0-9]+(-[a-z0-9]+)*$/) === null) {
        return false;
      }
      return true;
    }, value => {
      if (!value) {
        return {
          message: "Value is required."
        };
      }
      return {
        message: "Slug must consist of only 'a-z', '0-9' and '-' and be max 100 characters long (for example: 'some-slug' or 'some-slug-2')"
      };
    }),
    name: _zod.default.string().min(1).max(100),
    icon: _zod.default.string().max(255),
    description: _zod.default.string().min(1).max(100)
  });
};
exports.createBlockCategoryCreateValidation = createBlockCategoryCreateValidation;
const createBlockCategoryUpdateValidation = () => {
  return _zod.default.object({
    name: _zod.default.string().min(1).max(100),
    icon: _zod.default.string().max(255),
    description: _zod.default.string().min(1).max(100)
  }).partial();
};
exports.createBlockCategoryUpdateValidation = createBlockCategoryUpdateValidation;

//# sourceMappingURL=validation.js.map